/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_pl extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AUD" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNY", "CNY" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GBP", "GBP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HKD", "HKD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "ILS", "ILS" },
            { "INR", "INR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "JPY" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRW", "KRW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "NZD" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "z\u0142" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TWD", "TWD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VES", "VES" },
            { "VND", "VND" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "adp", "peseta andorska" },
            { "aed", "dirham ZEA" },
            { "afa", "afgani (1927\u20132002)" },
            { "afn", "afgani afga\u0144skie" },
            { "all", "lek alba\u0144ski" },
            { "amd", "dram arme\u0144ski" },
            { "ang", "gulden antylski" },
            { "aoa", "kwanza angolska" },
            { "aok", "kwanza angola\u0144ska (1977\u20131990)" },
            { "aon", "nowa kwanza angola\u0144ska (1990\u20132000)" },
            { "aor", "kwanza angola\u0144ska Reajustado (1995\u20131999)" },
            { "ara", "austral argenty\u0144ski" },
            { "arp", "peso argenty\u0144skie (1983\u20131985)" },
            { "ars", "peso argenty\u0144skie" },
            { "ats", "szyling austriacki" },
            { "aud", "dolar australijski" },
            { "awg", "florin aruba\u0144ski" },
            { "azm", "manat azerbejd\u017ca\u0144ski" },
            { "azn", "manat azerski" },
            { "bad", "dinar Bo\u015bni i Hercegowiny" },
            { "bam", "marka zamienna Bo\u015bni i Hercegowiny" },
            { "bbd", "dolar Barbadosu" },
            { "bdt", "taka bengalska" },
            { "bec", "frank belgijski (zamienny)" },
            { "bef", "frank belgijski" },
            { "bel", "frank belgijski (finansowy)" },
            { "bgl", "lew bu\u0142garski wymienny" },
            { "bgm", "lew bu\u0142garski socjalistyczny" },
            { "bgn", "lew bu\u0142garski" },
            { "bgo", "lew bu\u0142garski (1879\u20131952)" },
            { "bhd", "dinar bahra\u0144ski" },
            { "bif", "frank burundyjski" },
            { "bmd", "dolar bermudzki" },
            { "bnd", "dolar brunejski" },
            { "bob", "boliviano boliwijskie" },
            { "bop", "peso boliwijskie" },
            { "bov", "mvdol boliwijski" },
            { "brb", "cruzeiro novo brazylijskie (1967\u20131986)" },
            { "brc", "cruzado brazylijskie" },
            { "bre", "cruzeiro brazylijskie (1990\u20131993)" },
            { "brl", "real brazylijski" },
            { "brn", "nowe cruzado brazylijskie" },
            { "brr", "cruzeiro brazylijskie" },
            { "bsd", "dolar bahamski" },
            { "btn", "ngultrum bhuta\u0144ski" },
            { "buk", "kyat birma\u0144ski" },
            { "bwp", "pula botswa\u0144ska" },
            { "byb", "rubel bia\u0142oruski (1994\u20131999)" },
            { "byn", "rubel bia\u0142oruski" },
            { "byr", "rubel bia\u0142oruski (2000\u20132016)" },
            { "bzd", "dolar belize\u0144ski" },
            { "cad", "dolar kanadyjski" },
            { "cdf", "frank kongijski" },
            { "chf", "frank szwajcarski" },
            { "clp", "peso chilijskie" },
            { "cnh", "juan chi\u0144ski (rynek zewn\u0119trzny)" },
            { "cny", "juan chi\u0144ski" },
            { "cop", "peso kolumbijskie" },
            { "crc", "colon kostaryka\u0144ski" },
            { "csd", "stary dinar serbski" },
            { "csk", "korona czechos\u0142owacka" },
            { "cuc", "peso kuba\u0144skie wymienialne" },
            { "cup", "peso kuba\u0144skie" },
            { "cve", "escudo zielonoprzyl\u0105dkowe" },
            { "cyp", "funt cypryjski" },
            { "czk", "korona czeska" },
            { "ddm", "wschodnia marka wschodnioniemiecka" },
            { "dem", "marka niemiecka" },
            { "djf", "frank d\u017cibutyjski" },
            { "dkk", "korona du\u0144ska" },
            { "dop", "peso dominika\u0144skie" },
            { "dzd", "dinar algierski" },
            { "ecs", "sucre ekwadorski" },
            { "eek", "korona esto\u0144ska" },
            { "egp", "funt egipski" },
            { "ern", "nakfa erytrejska" },
            { "esa", "peseta hiszpa\u0144ska (Konto A)" },
            { "esb", "peseta hiszpa\u0144ska (konto wymienne)" },
            { "esp", "peseta hiszpa\u0144ska" },
            { "etb", "birr etiopski" },
            { "eur", "euro" },
            { "fim", "marka fi\u0144ska" },
            { "fjd", "dolar fid\u017cyjski" },
            { "fkp", "funt falklandzki" },
            { "frf", "frank francuski" },
            { "gbp", "funt szterling" },
            { "gek", "kupon gruzi\u0144ski larit" },
            { "gel", "lari gruzi\u0144skie" },
            { "ghc", "cedi gha\u0144skie (1979\u20132007)" },
            { "ghs", "cedi gha\u0144skie" },
            { "gip", "funt gibraltarski" },
            { "gmd", "dalasi gambijskie" },
            { "gnf", "frank gwinejski" },
            { "gns", "syli gwinejskie" },
            { "gqe", "ekwele gwinejskie Gwinei R\u00f3wnikowej" },
            { "grd", "drachma grecka" },
            { "gtq", "quetzal gwatemalski" },
            { "gwe", "escudo Gwinea Portugalska" },
            { "gwp", "peso Guinea-Bissau" },
            { "gyd", "dolar guja\u0144ski" },
            { "hkd", "dolar hongko\u0144ski" },
            { "hnl", "lempira honduraska" },
            { "hrd", "dinar chorwacki" },
            { "hrk", "kuna chorwacka" },
            { "htg", "gourde haita\u0144ski" },
            { "huf", "forint w\u0119gierski" },
            { "idr", "rupia indonezyjska" },
            { "iep", "funt irlandzki" },
            { "ilp", "funt izraelski" },
            { "ils", "nowy szekel izraelski" },
            { "inr", "rupia indyjska" },
            { "iqd", "dinar iracki" },
            { "irr", "rial ira\u0144ski" },
            { "isk", "korona islandzka" },
            { "itl", "lir w\u0142oski" },
            { "jmd", "dolar jamajski" },
            { "jod", "dinar jorda\u0144ski" },
            { "jpy", "jen japo\u0144ski" },
            { "kes", "szyling kenijski" },
            { "kgs", "som kirgiski" },
            { "khr", "riel kambod\u017ca\u0144ski" },
            { "kmf", "frank komoryjski" },
            { "kpw", "won p\u00f3\u0142nocnokorea\u0144ski" },
            { "krw", "won po\u0142udniowokorea\u0144ski" },
            { "kwd", "dinar kuwejcki" },
            { "kyd", "dolar kajma\u0144ski" },
            { "kzt", "tenge kazachskie" },
            { "lak", "kip laota\u0144ski" },
            { "lbp", "funt liba\u0144ski" },
            { "lkr", "rupia lankijska" },
            { "lrd", "dolar liberyjski" },
            { "lsl", "loti Lesoto" },
            { "ltl", "lit litewski" },
            { "ltt", "talon litewski" },
            { "luf", "frank luksemburski" },
            { "lvl", "\u0142at \u0142otewski" },
            { "lvr", "rubel \u0142otewski" },
            { "lyd", "dinar libijski" },
            { "mad", "dirham maroka\u0144ski" },
            { "maf", "frank maroka\u0144ski" },
            { "mdl", "lej mo\u0142dawski" },
            { "mga", "ariary malgaski" },
            { "mgf", "frank malgaski" },
            { "mkd", "denar macedo\u0144ski" },
            { "mlf", "frank malijski" },
            { "mmk", "kiat birma\u0144ski" },
            { "mnt", "tugrik mongolski" },
            { "mop", "pataca Makau" },
            { "mro", "ouguiya maureta\u0144ska (1973\u20132017)" },
            { "mru", "ugija maureta\u0144ska" },
            { "mtl", "lira malta\u0144ska" },
            { "mtp", "funt malta\u0144ski" },
            { "mur", "rupia maurytyjska" },
            { "mvr", "rupia malediwska" },
            { "mwk", "kwacha malawijska" },
            { "mxn", "peso meksyka\u0144skie" },
            { "mxp", "peso srebrne meksyka\u0144skie (1861\u20131992)" },
            { "myr", "ringgit malezyjski" },
            { "mze", "escudo mozambickie" },
            { "mzm", "metical Mozambik" },
            { "mzn", "metical mozambicki" },
            { "nad", "dolar namibijski" },
            { "ngn", "naira nigeryjska" },
            { "nic", "cordoba nikaragua\u0144ska (1988\u20131991)" },
            { "nio", "cordoba nikaragua\u0144ska" },
            { "nlg", "gulden holenderski" },
            { "nok", "korona norweska" },
            { "npr", "rupia nepalska" },
            { "nzd", "dolar nowozelandzki" },
            { "omr", "rial oma\u0144ski" },
            { "pab", "balboa panamski" },
            { "pei", "inti peruwia\u0144ski" },
            { "pen", "sol peruwia\u0144ski" },
            { "pes", "sol peruwia\u0144ski (1863\u20131965)" },
            { "pgk", "kina papua\u0144ska" },
            { "php", "peso filipi\u0144skie" },
            { "pkr", "rupia pakista\u0144ska" },
            { "pln", "z\u0142oty polski" },
            { "plz", "z\u0142oty polski (1950\u20131995)" },
            { "pte", "escudo portugalskie" },
            { "pyg", "guarani paragwajskie" },
            { "qar", "rial katarski" },
            { "rhd", "dolar rodezyjski" },
            { "rol", "lej rumu\u0144ski (1952\u20132006)" },
            { "ron", "lej rumu\u0144ski" },
            { "rsd", "dinar serbski" },
            { "rub", "rubel rosyjski" },
            { "rur", "rubel rosyjski (1991\u20131998)" },
            { "rwf", "frank ruandyjski" },
            { "sar", "rial saudyjski" },
            { "sbd", "dolar Wysp Salomona" },
            { "scr", "rupia seszelska" },
            { "sdd", "dinar suda\u0144ski" },
            { "sdg", "funt suda\u0144ski" },
            { "sdp", "funt suda\u0144ski (1957\u20131998)" },
            { "sek", "korona szwedzka" },
            { "sgd", "dolar singapurski" },
            { "shp", "funt \u015awi\u0119tej Heleny" },
            { "sit", "tolar s\u0142owe\u0144ski" },
            { "skk", "korona s\u0142owacka" },
            { "sll", "leone sierraleo\u0144ski" },
            { "sos", "szyling somalijski" },
            { "srd", "dolar surinamski" },
            { "srg", "gulden surinamski" },
            { "ssp", "funt po\u0142udniowosuda\u0144ski" },
            { "std", "dobra Wysp \u015awi\u0119tego Tomasza i Ksi\u0105\u017c\u0119cej (1977\u20132017)" },
            { "stn", "dobra Wysp \u015awi\u0119tego Tomasza i Ksi\u0105\u017c\u0119cej" },
            { "sur", "rubel radziecki" },
            { "svc", "colon salwadorski" },
            { "syp", "funt syryjski" },
            { "szl", "lilangeni Suazi" },
            { "thb", "baht tajski" },
            { "tjr", "rubel tad\u017cycki" },
            { "tjs", "somoni tad\u017cyckie" },
            { "tmm", "manat turkme\u0144ski (1993\u20132009)" },
            { "tmt", "manat turkme\u0144ski" },
            { "tnd", "dinar tunezyjski" },
            { "top", "pa\u2019anga tongijska" },
            { "tpe", "escudo timorskie" },
            { "trl", "lira turecka (1922\u20132005)" },
            { "try", "lira turecka" },
            { "ttd", "dolar Trynidadu i Tobago" },
            { "twd", "nowy dolar tajwa\u0144ski" },
            { "tzs", "szyling tanza\u0144ski" },
            { "uah", "hrywna ukrai\u0144ska" },
            { "uak", "karbowaniec ukrai\u0144ski" },
            { "ugs", "szyling ugandyjski (1966\u20131987)" },
            { "ugx", "szyling ugandyjski" },
            { "usd", "dolar ameryka\u0144ski" },
            { "uyp", "peso urugwajskie (1975\u20131993)" },
            { "uyu", "peso urugwajskie" },
            { "uzs", "som uzbecki" },
            { "veb", "boliwar wenezuelski (1871\u20132008)" },
            { "vef", "boliwar wenezuelski (2008\u20132018)" },
            { "ves", "boliwar wenezuelski" },
            { "vnd", "dong wietnamski" },
            { "vuv", "vatu wanuackie" },
            { "wst", "tala samoa\u0144skie" },
            { "xaf", "frank CFA BEAC" },
            { "xag", "srebro" },
            { "xau", "z\u0142oto" },
            { "xbc", "europejska jednostka rozrachunkowa (XBC)" },
            { "xbd", "europejska jednostka rozrachunkowa (XBD)" },
            { "xcd", "dolar wschodniokaraibski" },
            { "xdr", "specjalne prawa ci\u0105gnienia" },
            { "xeu", "ECU" },
            { "xfo", "frank z\u0142oty francuski" },
            { "xfu", "UIC-frank francuski" },
            { "xof", "frank CFA" },
            { "xpd", "pallad" },
            { "xpf", "frank CFP" },
            { "xpt", "platyna" },
            { "xts", "testowy kod waluty" },
            { "xxx", "nieznana waluta" },
            { "ydd", "dinar jeme\u0144ski" },
            { "yer", "rial jeme\u0144ski" },
            { "yum", "nowy dinar jugos\u0142awia\u0144ski" },
            { "yun", "dinar jugos\u0142awia\u0144ski wymienny" },
            { "zal", "rand po\u0142udniowoafryka\u0144ski (finansowy)" },
            { "zar", "rand po\u0142udniowoafryka\u0144ski" },
            { "zmk", "kwacha zambijska (1968\u20132012)" },
            { "zmw", "kwacha zambijska" },
            { "zrn", "nowy zair zairski" },
            { "zrz", "zair zairski" },
            { "zwd", "dolar Zimbabwe (1980\u20132008)" },
            { "zwl", "dolar Zimbabwe (2009)" },
            { "zwr", "dolar Zimbabwe (2008)" },
        };
        return data;
    }
}
